=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2005-09-08 00:40:15 +0000
+++ bzrlib/branch.py	2005-09-08 11:08:13 +0000
@@ -883,28 +883,6 @@
         commit(self, *args, **kw)
         
 
-    def lookup_revision(self, revision):
-        """Return the revision identifier for a given revision specifier."""
-        # XXX: I'm not sure this method belongs here; I'd rather have the
-        # revision spec stuff be an UI thing, and branch blissfully unaware
-        # of it.
-        # Also, I'm not entirely happy with this method returning None
-        # when the revision doesn't exist.
-        # But I'm keeping the contract I found, because this seems to be
-        # used in a lot of places - and when I do change these, I'd rather
-        # figure out case-by-case which ones actually want to care about
-        # revision specs (eg, they are UI-level) and which ones should trust
-        # that they have a revno/revid.
-        #   -- lalo@exoweb.net, 2005-09-07
-        from bzrlib.errors import NoSuchRevision
-        from bzrlib.revisionspec import RevisionSpec
-        try:
-            spec = RevisionSpec(self, revision)
-        except NoSuchRevision:
-            return None
-        return spec.rev_id
-
-
     def revision_id_to_revno(self, revision_id):
         """Given a revision id, return its revno"""
         history = self.revision_history()

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-09-08 00:40:15 +0000
+++ bzrlib/builtins.py	2005-09-08 11:08:13 +0000
@@ -199,7 +199,7 @@
             if len(revision) > 1:
                 raise BzrCommandError('bzr inventory --revision takes'
                     ' exactly one revision identifier')
-            inv = b.get_revision_inventory(b.lookup_revision(revision[0]))
+            inv = b.get_revision_inventory(RevisionSpec(b, revision[0]).rev_id)
 
         for path, entry in inv.entries():
             if show_ids:
@@ -748,7 +748,7 @@
         if revision == None:
             tree = b.working_tree()
         else:
-            tree = b.revision_tree(b.lookup_revision(revision))
+            tree = b.revision_tree(RevisionSpec(b, revision).rev_id)
 
         for fp, fc, kind, fid in tree.list_files():
             if verbose:
@@ -1184,15 +1184,15 @@
             other = [branch, -1]
         else:
             if len(revision) == 1:
-                other = [branch, revision[0]]
                 base = [None, None]
+                other = [branch, RevisionSpec(branch, revision[0]).revno]
             else:
                 assert len(revision) == 2
                 if None in revision:
                     raise BzrCommandError(
                         "Merge doesn't permit that revision specifier.")
-                base = [branch, revision[0]]
-                other = [branch, revision[1]]
+                base = [branch, RevisionSpec(branch, revision[0]).revno]
+                other = [branch, RevisionSpec(branch, revision[1]).revno]
 
         try:
             merge(other, base, check_clean=(not force), merge_type=merge_type)

=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2005-08-25 05:58:05 +0000
+++ bzrlib/diff.py	2005-09-08 11:08:13 +0000
@@ -156,17 +156,19 @@
     The more general form is show_diff_trees(), where the caller
     supplies any two trees.
     """
+    # XXX: the RevisionSpec stuff should be done by the caller (UI) code
     import sys
+    from bzrlib.revisionspec import RevisionSpec
 
     if revision == None:
         old_tree = b.basis_tree()
     else:
-        old_tree = b.revision_tree(b.lookup_revision(revision))
+        old_tree = b.revision_tree(RevisionSpec(b, revision).rev_id)
 
     if revision2 == None:
         new_tree = b.working_tree()
     else:
-        new_tree = b.revision_tree(b.lookup_revision(revision2))
+        new_tree = b.revision_tree(RevisionSpec(b, revision2).rev_id)
 
     show_diff_trees(old_tree, new_tree, sys.stdout, specific_files,
                     external_diff_options)

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2005-09-07 01:34:07 +0000
+++ bzrlib/merge.py	2005-09-08 11:08:13 +0000
@@ -139,7 +139,7 @@
     elif revno == -1:
         revision = branch.last_patch()
     else:
-        revision = branch.lookup_revision(revno)
+        revision = branch.get_rev_id(revno)
     return branch, get_revid_tree(branch, revision, temp_root, label,
                                   local_branch)
 
@@ -258,7 +258,7 @@
             other_rev_id = other_branch.last_patch()
             other_basis = other_rev_id
         elif other_revision[1] is not None:
-            other_rev_id = other_branch.lookup_revision(other_revision[1])
+            other_rev_id = other_branch.get_rev_id(other_revision[1])
             other_basis = other_rev_id
         else:
             other_rev_id = None
@@ -278,7 +278,7 @@
             elif base_revision[1] is None:
                 base_rev_id = None
             else:
-                base_rev_id = base_branch.lookup_revision(base_revision[1])
+                base_rev_id = base_branch.get_rev_id(base_revision[1])
             if base_rev_id is not None:
                 base_is_ancestor = is_ancestor(this_rev_id, base_rev_id, 
                                                MultipleRevisionSources(this_branch, 

=== modified file 'bzrlib/revisionspec.py'
--- bzrlib/revisionspec.py	2005-09-08 00:40:15 +0000
+++ bzrlib/revisionspec.py	2005-09-08 11:08:13 +0000
@@ -100,7 +100,6 @@
             return False
         if type(other) is type(self) and self.branch is not other.branch:
             return False
-        print 'comparing', tuple(self), tuple(other)
         return tuple(self) == tuple(other)
 
     def __repr__(self):

=== modified file 'bzrlib/selftest/versioning.py'
--- bzrlib/selftest/versioning.py	2005-08-30 03:10:32 +0000
+++ bzrlib/selftest/versioning.py	2005-09-08 11:08:13 +0000
@@ -155,8 +155,8 @@
             
         run_bzr('commit', 'a', '-m', 'commit a only')
         
-        old = b.revision_tree(b.lookup_revision(1))
-        new = b.revision_tree(b.lookup_revision(2))
+        old = b.revision_tree(b.get_rev_id(1))
+        new = b.revision_tree(b.get_rev_id(2))
         
         eq(new.get_file_by_path('b/two').read(), 'old contents')
         eq(new.get_file_by_path('top').read(), 'old contents')
@@ -165,14 +165,14 @@
         os.chdir('a')
         # commit from here should do nothing
         run_bzr('commit', '.', '-m', 'commit subdir only', '--unchanged')
-        v3 = b.revision_tree(b.lookup_revision(3))
+        v3 = b.revision_tree(b.get_rev_id(3))
         eq(v3.get_file_by_path('b/two').read(), 'old contents')
         eq(v3.get_file_by_path('top').read(), 'old contents')
         eq(v3.get_file_by_path('a/one').read(), 'new contents')
                 
         # commit in subdirectory commits whole tree
         run_bzr('commit', '-m', 'commit whole tree from subdir')
-        v4 = b.revision_tree(b.lookup_revision(4))
+        v4 = b.revision_tree(b.get_rev_id(4))
         eq(v4.get_file_by_path('b/two').read(), 'new contents')        
         eq(v4.get_file_by_path('top').read(), 'new contents')
         

